#
# spec file for package labplot-kf5
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if "%{?_kf5_appstreamdir}" == ""
# it's not defined in Leap 42.1, so define it appropriately in that case
%define _kf5_appstreamdir %{_kf5_sharedir}/appdata
%endif
Name:           labplot-kf5
Version:        2.9.0
Release:        1.4
Summary:        KDE Framework 5 data analysis and visualization application
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Other
URL:            https://labplot.kde.org/
Source:         https://download.kde.org/stable/labplot/%{version}/labplot-%{version}.tar.xz
BuildRequires:  bison
BuildRequires:  cantor-devel
BuildRequires:  extra-cmake-modules
BuildRequires:  fdupes
BuildRequires:  hdf5-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  kf5-filesystem
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  cmake(KF5Archive)
BuildRequires:  cmake(KF5Completion)
BuildRequires:  cmake(KF5Config)
BuildRequires:  cmake(KF5ConfigWidgets)
BuildRequires:  cmake(KF5CoreAddons)
BuildRequires:  cmake(KF5Crash)
BuildRequires:  cmake(KF5DocTools)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5IconThemes)
BuildRequires:  cmake(KF5KIO)
BuildRequires:  cmake(KF5NewStuff)
BuildRequires:  cmake(KF5Parts)
BuildRequires:  cmake(KF5Service)
BuildRequires:  cmake(KF5SyntaxHighlighting)
BuildRequires:  cmake(KF5TextWidgets)
BuildRequires:  cmake(KF5WidgetsAddons)
BuildRequires:  cmake(KF5XmlGui)
BuildRequires:  cmake(Qt5Concurrent)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5PrintSupport)
BuildRequires:  cmake(Qt5SerialPort)
BuildRequires:  cmake(Qt5Sql)
BuildRequires:  cmake(Qt5Svg)
BuildRequires:  cmake(Qt5Test)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  pkgconfig(cfitsio)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(gsl)
BuildRequires:  pkgconfig(libcerf)
BuildRequires:  pkgconfig(liblz4)
BuildRequires:  pkgconfig(liborigin)
BuildRequires:  pkgconfig(matio)
BuildRequires:  pkgconfig(netcdf)
BuildRequires:  pkgconfig(poppler-qt5)
BuildRequires:  pkgconfig(shared-mime-info)
BuildRequires:  pkgconfig(zlib)
Provides:       labplot = %{version}
Obsoletes:      labplot < 2.3.0
%lang_package

%description
LabPlot is a KDE application for interactive graphing and analysis
of scientific data. LabPlot provides an easy way to create, manage
and edit plots. It allows you to produce plots based on data from a
spreadsheet or on data imported from external files. Plots can be
exported to several pixmap and vector graphic formats.

This version is based on KDE Frameworks 5

%prep
%setup -q -n labplot-%{version}

%build
%cmake_kf5 -d build -- -DENABLE_READSTAT:BOOL=OFF -DREPRODUCIBLE_BUILD:BOOL=ON
%cmake_build

%install
%kf5_makeinstall -C build

%find_lang labplot2 --with-man %{?no_lang_C}

%fdupes -s %{buildroot}

%kf5_post_install

%files
%license LICENSES/*
%doc AUTHORS ChangeLog README.md
%{_kf5_bindir}/labplot2
%{_kf5_appsdir}/labplot2/
%{_kf5_applicationsdir}/org.kde.labplot2.desktop
%dir %{_kf5_iconsdir}/hicolor/44x44/
%dir %{_kf5_iconsdir}/hicolor/44x44/apps/
%dir %{_kf5_iconsdir}/hicolor/150x150/
%dir %{_kf5_iconsdir}/hicolor/150x150/apps/
%dir %{_kf5_iconsdir}/hicolor/310x310/
%dir %{_kf5_iconsdir}/hicolor/310x310/apps/
%dir %{_kf5_iconsdir}/hicolor/512x512/
%dir %{_kf5_iconsdir}/hicolor/512x512/apps/
%{_kf5_iconsdir}/hicolor/scalable/apps/labplot-*
%{_kf5_iconsdir}/hicolor/*/apps/labplot2.*
%{_kf5_kxmlguidir}/labplot2/
%{_kf5_sharedir}/mime/packages/labplot2.xml
%dir %{_kf5_appstreamdir}
%{_kf5_appstreamdir}/org.kde.labplot2.appdata.xml
%{_kf5_htmldir}/en/labplot2/
%{_kf5_mandir}/man1/labplot2.1%{?ext_man}

%files lang -f labplot2.lang
%{_kf5_htmldir}/*/labplot2/
## These belong to the main package
%exclude %{_kf5_htmldir}/en/labplot2/

%changelog
* Wed May  4 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 2.9.0. Check the Changelog file for the full list
  of changes. Bugs fixed since the last version:
  * Fitting: Fix missing locale support in evaluating range of
    fit function
  * Fitting: Fix pseudovoigt model
  * Fix crash in convolution and correlation
  * Windows: use breeze as default for better dark mode
  * Properly save the geometry of visible windows in the project
  * Interpolation: avoid crash when x data contains invalid data
    points or is not strictly increasing
  * HDF5: Fix reading attribute strings and better handle strings
    in compound data
* Tue Mar 30 2021 Wolfgang Bauer <wbauer@tmo.at>
- Update to version 2.8.2
- Bug fixes:
  * [CAS]
    + Fixed the regression introduced after the python2 backend was
    deprecated in Cantor
    + Warn about the potential data looses when a project with CAS
    content is opened but no CAS support is available
  * [worksheet]:
    + DateTime support for Custom Points and for Histograms
    + Fix "power of" notations for negative values, show "0" for
    zero and improve auto precision for small values for axis
    labels
    + Show all available symbols styles for CustomPoint, the last
    one was missing
    + Convert the plot range format to datetime also when the first
    histogram for datetime data was added to the plot
    + Properly restore the saved values column and also save the
    values formatting properties in the histogram
    + If the deleted columns are being restored, restore the column
    pointers also in the histograms
    + Properly react in the histogram when data columns are deleted
    or renamed
    + Save/load the values format in xy-curve
    + React on text changes for values prefix and suffix and not on
    return pressed event in the curve properties explorer
    + Fix log scale axis for one tick and ln-scale typo
    + Fix sqrt and square axis scales
    + adjust the range format (numeric vs. datetime) also when the
    column of the first curve is changed and not only when a new
    curve is added
    + simplified the naming of the initial axes for the default
    plot types (box blot with four axes,  etc.) - use "x" instead
    of "x axis 1", etc.
    + export to more image formats (jpg, bmp, ppm, xbm, xpm)
  * [spreadsheet]
    + show column statistics also for bigint columns
    + when selecting a column in the project explorer, make sure it
    becomes visible in the spreadsheet by scrolling horizontally
    to its position
    + when removing or inserting rows in the spreadsheet, properly
    update the headers in the spreadsheet
  * [import]
    + Don't try to parse a netCDF file when the application was
    compiled without any support for netCDF, and similar for
    other formats
    + Show the last recently imported projects in a combobox also
    in ImportProjectDialog similar to how it's already done in
    ImportFileDialog
    + Don't show any error messages when the source file or local
    socket is empty when the import dialog is opened for the
    first time
    + Fixed ASCII import when start column > 1
  * Don't change the current selection in the Project Explorer when
    objects are being added or removed during undo or redo
  * Improved LaTeX support in export dialog and export of big
    spreadsheets
  * Fixed resetting parser error count on some platforms
    (kde#427190)
  * Support semicolon as function argument separator for locale
    with comma as decimal separator (kde#429110)
  * Fix validation of custom model equation in fit dock
    (kde#429368)
  * Save/Load value format (kde#431535)
  * Show the relevant parts of the drop lines also when the data
    points are outside of the plot range (kde#432291)
* Fri Nov 13 2020 Wolfgang Bauer <wbauer@tmo.at>
- Update to version 2.8.1
- New features:
  * [worksheet] allow to change the background color for axis
    labels (default: transparent)
  * [worksheet] allow to copy the plot cursor cordinates
  * [spreadsheet] better auto-detection of datetime format for
    values pasted in the spreadsheet
  * [live data] allow to add the timestamp column for all network
    live sources (TCP/UDP), not only for MQTT
  * [live data] better error handling and user notifications
- Bug fixes:
  * Fix compiling with Cantor 20.08.X and X>0
  * Fix drawing lines between points of datetime data
  * Fix drawing axis tick label in color when in HTML mode
  * Fix size of dock widgets when changing between them
  * Remove sub-window shadow remnants when closing the project
    (kde#389920)
  * Fix changing font of text label for newer Qt versions
    (kde#428029)
  * Fix full screen not restored (also fixes full screen on macOS)
    (kde#428813)
  * Don't crash when doing drag&drop between different main windows
    (kde#428698)
  * Fix missing settings dialog on macOS
  * Parser improvements (found in "Generate Function Values"):
    + Fix Crash using variable name of pre-defined functions as
    function ("sin()")
    + Allow variable names containing function names ("sina")
    + Correctly remove variables when changing name
    + Use application number locale
    + insert predefined functions with correct number of arguments
- Drop fix_labplot_assumption_cantor_version.patch, merged upstream
- Drop obsolete %%post/%%postun scriptlets, the used macros are
  no-ops since Leap 15.0
* Sat Oct 10 2020 wbauer@tmo.at
- Update fix_labplot_assumption_cantor_version.patch to fix build
  with cantor 20.08.2 and later
* Fri Sep 25 2020 wbauer@tmo.at
- Move english docs from labplot-kf5-lang to the main package again
- Remove unused Qt5Qml BuildRequires
* Wed Sep 16 2020 andy great <andythe_great@pm.me>
- Update to version 2.8.0.
  * New features:
  * Improved DateTime data support
  * Show the size of the members in the JSON file in the import
    file dialog
  * [worksheet] In the Export Worksheet Dialog allow to export to
    the clipboard
  * [worksheet] Allow to move plots, text labels and legend with
    arrow keys
  * [worksheet] Image worksheet element
  * [worksheet] Reference line on the plot
  * [worksheet] Support for imperial units for geometry and size
    settings of objects
  * [worksheet] Improve axes major and minor tick settings
  * [spreadsheet] show infinite values as such and not as NaN
  * [spreadsheet] support big integer (64 bit) as data type
  * [spreadsheet] column normalization methods "divide by max",
    "divide by min", etc.
  * [spreadsheet] Tukey's ladder of powers
  * [spreadsheet] added the size of the data set, its mode, 1st
    and 3rd quartiles and IQR to the column statistics
  * [analysis] calculate and expose the rough values as the
    result of a smooth (data = smooth + rough)
  * Allow to open Cantor and Jupyter projects
  * [Windows] improved craft blueprint and installer package
  * [macOS] added support for touchbar
  * Support global user specified decimal separator
  * Improved locale support in number input fields
  * Extended "About"-Dialog
  * Bug fixes:
  * BUG: 421193 - import float(4) data from hdf5
  * BUG: 418390 - Ignore infinite values (created in CAS
    worksheets for example) in curves
  * BUG: 412455 - Don't crash (sporadically) when opening the
    color scheme menu
  * BUG: 415214 - Better algorithm to draw the error bar caps
  * BUG: 413397 - Properly handle removal of columns in the
    spreadsheet model
  * BUG: 413401 - In plot data dialog, don't add new worksheets
    as children to workbooks, use the proper parent aspect
  * Fix Cantor support and Unicode characters on Windows
  * Fix evaluating fit residuals
- Add fix_labplot_assumption_cantor_version.patch to fix Labplot 2.8.0
  wrong assumption that Cantor 20.08.1 has a new interface.
* Fri Oct 25 2019 wbauer@tmo.at
- Update to version 2.7.0
- New features:
  * Allow to move objects (drag&drop) to different folders in the
    project explorer
  * [spreadsheet] allow to insert multiple rows and columns in one
    step
  * [spreadsheet] improved the handling of calculated columns
    (values calculated via a formula):
    + Allow to automatically update the calculated column on data
    changes in the variable columns
    + Invalidate the calculated column if one of the variable
    columns was deleted
    + In "Functions Values" dialog highlight the variable column
    combobox red if the variable column was deleted in the
    project
    + In "Functions Values" dialog don't allow to select columns to
    be calculated as variable columns (avoid circular
    dependencies)
    + In "Used in" context menu of a column show all other
    calculated columns where this column is used as a variable
  * [spreadsheet] when pasting data into empty columns,
    automatically convert their type to the type of the data to be
    pasted
  * support für directory structures in ROOT files (kde#406805)
  * Automatically update curves if a data column deleted before was
    re-added again (during the import or manually)
  * When auto-scaling in the plot take also the error bars into
    account, if available
  * For live data sources allow to save the relative path to the
    data source
- UX improvements:
  * in the "Import Data" dialog show the history of the recently
    imported files
  * Improved the selection of curves in the plot that are near to
    or behind each other
  * Allow to use DEL to delete cells in spreadsheet and matrix
    (kde#408529)
  * Allow to insert multiple rows and columns in the spreadsheet in
    one step (kde#408537)
  * Added translations to Windows and macOS packages
  * Allow to stop the current selection in the plot with ESC
  * Seed the random number generator with the current time in order
    not to generate repetitive numbers in the spreadsheet
    (kde#410855)
- Performance:
  * Increased the plotting speed for curves with many data points
    by removing points which are shown on the same pixel in the
    scene
- Bug fixes:
  * Disable autoscale when zooming, otherwise wrong (= auto scaled)
    data region is shown after project save&open
  * [macOS] fix determining number of lines of data files
  * correctly show error bars for data source columns having NANs
    (kde#408530)
  * fixed the broken project import (kde#407847)
  * fixed missing option for the resolution of PNG files in the
    export dialog (kde#411122)
  * [data fitting] handle weighted fitting with zero errors
    correctly
  * [data fitting] allow weighted fitting with data source from
    curve
  * [data fitting] fix function for calculating bounded values
  * [nsl] fix memory leak in line simplification (Douglas Peuker
    variant)
  * [nsl] fix bug in calculating Bessel polynomials on Windows
    (used in Bessel filter)
- Run spec-cleaner
* Sat Jun  1 2019 wbauer@tmo.at
- Update to version 2.6.0
- New features:
  * Histogram
  * Import from MQTT sources
  * Import of ROOT (CERN) TH1 histograms
  * Import of Ngspice raw files (ASCII and binary)
  * Import of data in JSON format (JSON arrays and objects)
  * Improved import of NetCDF files
  * Added file type specific summary and content for special file
    types in info box of import dialog
  * Convolution/Deconvolution of data sets (sampling interval,
    linear/circular, normalization, wrap, standard kernel)
  * Cross-/Autocorrelation of data sets (sampling interval,
    linear/circular, normalization)
  * Allow to specify the number format when exporting spreadsheet
    and matrix
  * Improved user interface for data fitting (add fit function
    preview, show parameters directly, make options foldable)
  * [spreadsheet] when filling a float column with row numbers,
    automatically convert its type to integer
  * [spreadsheet] when filling an integer column with function
    values, automatically convert its type to float
  * [spreadsheet] data manipulation: add/subtract/multiply/divide
    for column values
  * [spreadsheet] export to SQLite
  * [matrix] data manipulation: add/subtract/multiply/divide for
    matrix values
  * [worksheet] Allow to specify different border shapes for labels
    (rectangle, eclipse, etc.)
  * [worksheet] Allow to rotate plot legends
  * [worksheet] Better positioning of rotated axis tick labels
  * [worksheet] Allow to make plots not-interactive (ignore mouse
    drag and wheel events) to avoid unwanted occasional panning and
    zooming
  * Allow to connect to SQL databases via ODBC
  * Show the amount of consumed memory in the status bar (optional)
  * Allow to change the settings for different computer algebra
    systems (Maxima, etc.) directly in LabPlot (embedd Cantor's
    settings widgets)
- Bug fixes:
  * Fixed several problems in live data support
  * [spreadsheet] properly calculate function values out of integer
    x-values
  * [matrix] fix editing integer values
  * [import] fix preview update and add missing close of netcdf
    files
  * Don't crash when a scaling factor equal to zero was set for
    axis
* Thu Jun 21 2018 wbauer@tmo.at
- Update to version 2.5.0
- New features:
  * Support for reading and plotting of live-data
  * Improved data fitting
    + Automatically guess parameter of custom models
    + Better result presentation
    + Support different weight types
    + Consider given x- and y-error when fitting (can be switched off)
    + Show t statistics, P > |t| and confidence interval
    + Calculate p-value for chi-square and F test in nonlinear fitting
    + added fit models for most statistical distributions
  * Improved theming
    + Apply themes to worksheet and to all its children
    + Respect theme settings also in plot legends and labels
    + Allow to disable theming in worksheets and plots after a theme
    was selected
    + Show currently active theme in the "Apply theme" button
    + New application option in the settings for the default theme
    used for new worksheets.
  * Support different data types
    + auto detect integer and datetime data in import
    + support number locale and datetime formats
    + improved data type support in spreadsheets
  * Import from SQL databases (tables or custom queries)
  * Import Origin OPJ projects
  * Much better support for Windows and macOS
  * Syntax highlighting for LaTeX in the text label
  * Allow to set the background color for LaTeX labels
  * Support Hermite polynomials from GSL 2.4
  * Support error functions and related functions from libcerf
  * "Used in" sub-menu in column contex menu for faster navigation
    to the curves consuming the column
  * Direct application of analysis functions (smoothing,
    interpolating, etc.) on the ploted data via curve's context menu
  * Direct application of analysis functions  on the data in the
    spreadsheet and plotting of the results via spreadsheet's context menu
  * Drag columns in the project explorer and drop them on plots (either in
    a worksheet view or in the project explorer) to create curves
  * "Show last N points" and "Show first N points" data ranges in cartesian plot
  * Added CLI option --presenter to start LabPlot directly in the presenter mode
  * Added CLI parameter to directly open project files (LabPlot or Origin)
  * Allow drag&drop of projects files (LabPlot and Origin) on the main
    window to load the project
  * Allow drag&drop of data files on the main window to import the data
  * Show tooltips for the supported mathematical functions and
    constants in the expression text field
  * Automatically switch to the scientific representation for numbers
    bigger than 10^4 on the axis tick labels
  * Automatically allow the latex typesetting in the application after
    the latex environment was installed later without making the user
    to go to the settings dialog
  * Allow to change the color scheme for the application
  * Smooth and animated zooming in the worksheet view
  * Allow to add text labels to plots
  * Improved building with MSVC, Intel and PGI compiler
- Performance improvements:
  * Faster copy&paste in the spreadsheet
- Bug fixes:
  * masked rows in spreadsheet not restored in project (kde#379877)
  * Calculation of fit results corrected
  * Axes now support values larger than FLT_MAX (~10^38) and smaller
    than FLT_MIN (~10^-38)
  * When a LabPlot project is being droped in the main window, load
    the project directly instead of showing the import file dialog
  * Correctly save and restore masked cells
  * Don't crash if the rc-file was not found during the startup
- Drop Fix-compilation-on-Qt5.11.patch, merged upstream
- Update Url to point to labplot's homepage
- Update build requirements
* Tue Jun  5 2018 wbauer@tmo.at
- Add Fix-compilation-on-Qt5.11.patch to fix build with Qt 5.11
* Wed May  3 2017 wbauer@tmo.at
- Update to version 2.4.0
- New features:
  * Support themes for plots
  * Import and editing of FITS data files
  * Data reduction by removing data points using multiple algorithms
  * Numerical differentiation and integration with several options
  * Many new pre-defined fit models (Gompertz, Weibull, Log-Normal,
    Gumbel, etc.) sorted in categories
  * Fit parameter now support fixed values, lower/upper limits and
    use Unicode
  * Fit model and random number distribution formulas are now
    rendered with LaTeX
  * Support user specified x range in all analysis functions
  * Allow to enter complete LaTeX documents in text labels
  * Configuration parameter to use different LaTex engines
    (LuaLaTex, XeLatex, pdfLaTex, LaTex)
  * Disable LaTeX typesetting if no LaTex installation (and other
    required tools) were found at runtime
  * Presenter mode for worksheets
  * Support for Mac OS
  * Support for Julia’s vectors and tuples in CAS worksheets
    (requires Cantor v. 16.12 or higher)
  * Allow to jump directly to the data source spreadsheet via
    XYCurve’s context menu
  * Select and delete multiple objects in project explorer
  * Improved and extended internal parser for mathematical expressions
  * Copy of worksheet elements as image to the clipboard via CTRL+C
- Bug fixes:
  * Allow to select curves with overlapping bounding boxes (kde#361326)
  * Correctly load worksheet sizes from saved templates
  * Fixed crash when removing columns in spreadsheet
  * Fixed crash when fitting using GSL >= 2
  * List of available functions corrected
  * Constants are now available with full accuracy
  * Windows: Import of files and open recent files fixed
- Drop upstreamed fix-desktop-file.patch
- Add new BuildRequires: cmake(KF5NewStuff)
- Do not rename the .desktop and appstream data files any more, the
  names have been changed upstream
* Mon Sep  5 2016 badshah400@gmail.com
- Add Provides: labplot = %%{version} and Obsoletes: labplot <
  2.3.0 to enable easy upgrade from openSUSE Leap 42.1 to 42.2,
  where labplot-kf5 2.3.0 should replace labplot. This assumes
  that the Leap 42.1 labplot (currently at version 2.0.2) itself
  does not get upgraded to a version above 2.3.0 via official
  maintenance updates. Remove Conflicts on labplot as a
  consequence.
* Wed Jul 27 2016 wbauer@tmo.at
- Add fix-desktop-file.patch to fix the Exec line in the .desktop
  file so labplot can be started from the application menu
- Add cantor-devel to the build requires to enable the new cantor
  integration
* Tue Jul 26 2016 wbauer@tmo.at
- Update to version 2.3.0
- New features:
  * Integration of Cantor - Support for different open-source
    computer algebra systems
  * Statistics on spreadsheets and matrices
  * Export of spreadsheets and matrices to LaTeX tables
  * Interpolation of data including different splines, cosine,
    exponential, cubic Hermite (Catmull-Rom, cardinal,
    Kochanek-Bartels) and rational functions
  * Data smoothing using moving average (centered or lagged),
    percentile filter or Savitzky-Golay algorithm
  * Fourier filter (low pass, high pass, band pass, band reject)
    with ideal, Butterworth, Chebychev I+II, Legendre or
    Bessel-Thomson filter
  * Fourier transform with many window functions (Welch, Hann,
    Hamming, etc.) calculating magnitude, amplitude, power, phase,
    dB, etc. and supporting one/two sided spectrum with or without
    shift and x scaling to frequency, index or period
  * Filter and search capabilities in the drop down box for the
    selection of data sources
  * Sigmoid function as a new pre-defined fit model
  * Support for compiling on Microsoft Windows
- Performance improvements:
  * Faster generation of random values
  * Global option to enable/disable the double-buffering for faster
    painting of curves (enabled on default)
- Bug fixes:
  * Save and restore last used setting in RandomValuesDialog
  * Update axis title shape on title rotations correctly
  * Save and restore custom column widths in the spreadsheet
  * Fixed sporadic crashes during project close
- Drop upstreamed labplot-kf5-gcc5-isnan.patch
* Fri Jul 15 2016 badshah400@gmail.com
- Labplot does not show up in application centers (e.g.
  gnome-software) as appstream-builder expects the .appdata.xml
  file and .desktop file to have matching names; rename .desktop
  file to org.kde.labplot2.desktop as referenced in the
  appdata.xml file, and rename appdata.xml file accordingly.
* Sun May  8 2016 badshah400@gmail.com
- Add labplot-kf5-gcc5-isnan.patch: Replace isnan by std::isnan
  to fix building with gcc5.
* Wed May  4 2016 mailaender@opensuse.org
- Update to version 2.2.0
  * Added the DataPicker which converts input graph (images) into numbers.
  * A new custom point was implemented
  * LabPlot now acccepts now drag&drop-events
  * Rendering of the image view of the matrix recieved a speed up
* Wed Oct 28 2015 toddrme2178@gmail.com
- Conflict with labplot, not labplot2.
* Mon Oct 26 2015 toddrme2178@gmail.com
- Initial Frameworks 5 version.
* Mon Oct 26 2015 toddrme2178@gmail.com
- Enable HDF5 and NetCDF support.  Support for these formats is
  considered stable now.
* Mon Oct 26 2015 freitag@owncloud.com
- Fixing build issues by upgrading to new upstream version 2.1.0
- 2.1.0 new features:
  * New Matrix view for handling matrix data.
  * Workbook - a new container for grouping several objects of type
    Spreadsheet and/or Matrix.
  * Import of binary, image, NetCDF and HDF data into spreadsheet or
    matrix.
  * Visual HDF and NetCDF parser to view content of files and import
    data sets.
  * Preview of all supported file types in import dialog.
  * Transparently import compressed data files.
  * In xy-curve the points may not be connected by the line if there
    are NANs in-between. This behaviour is controlled by the parameter
    "skip gaps".
  * Multiplier of Pi format of the plot axis for periodical functions.
  * New operations on columns in Spreadsheet - reverse, drop values
    and mask values.
  * Formula used to generate the values in a column is stored and can
    be changed/adjusted in the formula dialog afterwards.
  * Curve filling: the area below, under, left to or right to the
    curve can be filled.
  * Support for multiple variables in "Function Values"-dialog - new
    data in the spreadsheet can be calculated out of multiple columns.
- Performance improvements:
  * Speeded up the creation of new columns during the import
- Bug fixes:
  * Fixed wrong behaviour when doing "zoom&select" in a plot and then
    deselecting the plot - it was not possible anymore to select the
    plot again on the worksheet.
* Tue Apr 14 2015 mailaender@opensuse.org
- update to version 2.0.2
* Sat Nov 15 2014 dmitry_r@opensuse.org
- Install documentation
* Tue Apr 22 2014 dmitry_r@opensuse.org
- labplot 2.0 doesn't support HDF5, NetCDF and Origin file formats,
  so disable not needed build requirements
* Sun Feb  2 2014 mailaender@opensuse.org
- update to 2.0.1
  * Fixed wrong scaling of legend's text labels in pdf-export
  * Fixed memory corruption in CartesianPlotDock that can lead to crashes
* Sun Jan 19 2014 mailaender@opensuse.org
- update to release 2.0.0
* Sun Dec 22 2013 mailaender@opensuse.org
- update to 2.0.0.beta2
* Wed Oct 23 2013 mailaender@opensuse.org
- packaged re-release of 2.0.0.beta1 to fix segfault on startup
- https://en.opensuse.org/SourceUrls
- use pkgconfig where possible
* Mon Oct 21 2013 toddrme2178@gmail.com
- Update to 2.0.0 beta 1
  * No changelog
* Sat Feb 16 2013 dmitry_r@opensuse.org
- qwt no longer needed
- use external liborigin library
* Tue Dec 25 2012 mailaender@opensuse.org
- update to version 2.0.0.alpha3
* Fri Aug 31 2012 scorot@free.fr
- fix libpng deps for SLE_11
* Fri Aug 31 2012 scorot@free.fr
- fix build for old qt4 with patch0
* Sun May  6 2012 idonmez@suse.com
- Fix factory build
* Tue Feb 14 2012 alinm.elena@gmail.com
- initial commit
